@@ -11,10 +11,7 @@ from typing import Optional
 from hoppr import utils
 from hoppr.exceptions import HopprCredentialsError
 from hoppr.hoppr_types.cred_object import CredObject
-from hoppr.hoppr_types.credentials_file_content import (
-    CredentialFileContent,
-    CredentialRequiredService,
-)
+from hoppr.hoppr_types.credentials_file_content import CredentialFileContent, CredentialRequiredService
 
 
 class Credentials:
@@ -65,8 +62,6 @@ class Credentials:
                     f"'{pass_env}' not found in environment variables.",
                 )
 
-            return CredObject(
-                username=str(matching_service.user), password=environ[str(pass_env)]
-            )
+            return CredObject(username=str(matching_service.user), password=environ[str(pass_env)])
 
         return None
