@@ -4,9 +4,10 @@ Define context in which a plug-in runs
 from __future__ import annotations
 
 import logging
-import multiprocessing
+import threading
+
 from dataclasses import dataclass
-from typing import TYPE_CHECKING, Any, Optional
+from typing import TYPE_CHECKING
 
 # Only import these classes during type-checking
 #
@@ -17,9 +18,7 @@ from typing import TYPE_CHECKING, Any, Optional
 # If we don't import for type checking, mypy fails.
 
 if TYPE_CHECKING:  # pragma: no cover
-    from hoppr_cyclonedx_models.cyclonedx_1_4 import (
-        CyclonedxSoftwareBillOfMaterialsStandard as Bom,  # type: ignore
-    )
+    from hoppr_cyclonedx_models.cyclonedx_1_4 import CyclonedxSoftwareBillOfMaterialsStandard as Bom  # type: ignore
 
     from hoppr.configs.manifest import Manifest
 
@@ -35,8 +34,9 @@ class Context:  # pylint: disable="too-many-instance-attributes"
     consolidated_sbom: Bom
     delivered_sbom: Bom
     max_processes: int
+    logfile_lock: threading.RLock
     max_attempts: int = 3
     retry_wait_seconds: float = 5
-    logfile_lock: Optional[Any] = multiprocessing.Manager().RLock()
     logfile_location: str = "hoppr.log"
     log_level: int = logging.INFO
+    strict_repos: bool = True
