@@ -6,6 +6,8 @@ from dataclasses import dataclass
 from multiprocessing import cpu_count
 from typing import Optional
 
+from hoppr import constants
+
 
 @dataclass
 class Plugin:
@@ -28,7 +30,7 @@ class Stage:
         self.name: str = name
         self.component_coverage: Optional[str] = stage_config.get("component_coverage")
         self.plugins: list[Plugin] = []
-        for plugin in stage_config.get("plugins", []):
+        for plugin in stage_config.get(constants.ConfigKeys.PLUGINS, []):
             self.plugins.append(Plugin(**plugin))
 
 
