@@ -2,7 +2,10 @@
 Hoppr Network utility functions
 """
 
+from typing import Optional
+
 import requests
+
 from requests.auth import HTTPBasicAuth
 
 from hoppr.configs.credentials import Credentials
@@ -11,7 +14,7 @@ from hoppr.hoppr_types.cred_object import CredObject
 from hoppr.utils import load_string
 
 
-def load_url(url: str, creds: CredObject = None):
+def load_url(url: str, creds: Optional[CredObject] = None):
     """
     Load config content (either json or yml) from a url into a dict
     """
@@ -25,9 +28,7 @@ def load_url(url: str, creds: CredObject = None):
             "Authorization": f"Bearer {creds.password}",
         }
         basic_auth = HTTPBasicAuth(username=creds.username, password=creds.password)
-        response = requests.get(
-            url, auth=basic_auth, headers=authorization_headers, timeout=60
-        )
+        response = requests.get(url, auth=basic_auth, headers=authorization_headers, timeout=60)
     else:
         response = requests.get(url, timeout=60)
 
@@ -44,10 +45,7 @@ def load_url(url: str, creds: CredObject = None):
     except HopprLoadDataError as parse_error:
         message = f"Unable to parse result from {url}."
         if response.url != url:
-            message += (
-                f" Request was redirected to {response.url}. "
-                + "An auth issue might have occurred."
-            )
+            message += f" Request was redirected to {response.url}. An auth issue might have occurred."
         raise HopprLoadDataError(message) from parse_error
 
     if not valid_data:
@@ -67,9 +65,7 @@ def download_file(url, dest, creds=None):
     if creds is not None:
         basic_auth = HTTPBasicAuth(username=creds.username, password=creds.password)
 
-    response = requests.get(
-        url, auth=basic_auth, allow_redirects=True, stream=True, verify=True, timeout=60
-    )
+    response = requests.get(url, auth=basic_auth, allow_redirects=True, stream=True, verify=True, timeout=60)
 
     if 200 <= response.status_code and response.status_code < 300:
         with open(dest, "wb") as out_file:
