@@ -1,16 +1,17 @@
 """
 Hoppr utility functions
 """
+from __future__ import annotations
 
 import importlib
 import inspect
-import json
-from json.decoder import JSONDecodeError
+
 from pathlib import Path
-from typing import Any, Dict, List, Set
+from typing import Any
 
 import yaml
-from yaml.parser import ParserError as YamlParserError
+
+from yaml.parser import ParserError as YAMLParserError
 from yaml.scanner import ScannerError as YAMLScannerError
 
 from hoppr.context import Context
@@ -34,77 +35,91 @@ def _class_in_module(obj, module):
     return True
 
 
-def plugin_instance(plugin_name, context: Context, config: Any = None):
+def plugin_class(plugin_name):
+    """
+    return a concrete class of an object defined by a plugin name
+
+    Assumes the specified plugin will define exactly one concrete class, which
+    will be instaniated using a default constructor (i.e., one with no parameters).
+    """
+    try:
+        plugin = importlib.import_module(plugin_name)
+    except ModuleNotFoundError as mnfe:
+        raise ModuleNotFoundError(f"Unable to locate plug-in {plugin_name}: {mnfe}") from mnfe
+
+    plugin_cls = None
+
+    for name, obj in inspect.getmembers(plugin):
+        if _class_in_module(obj, plugin):
+
+            if plugin_cls is not None:
+                raise HopprPluginError(
+                    f"Multiple candidate classes defined in {plugin_name}: " + f"{plugin_cls.__name__}, {name}"
+                )
+
+            plugin_cls = obj
+
+    if plugin_cls is None:
+        raise HopprPluginError(f"No class definition found in in {plugin_name}.")
+
+    return plugin_cls
+
+
+def plugin_instance(plugin_name: str, context: Context, config: Any = None):
     """
     Create an instance of an object defined by a plugin name
 
     Assumes the specified plugin will define exactly one concrete class, which
     will be instaniated using a default constructor (i.e., one with no parameters).
     """
+    plugin_cls = plugin_class(plugin_name)
+
+    return plugin_cls(context=context, config=config)
+
+
+def load_string(contents: str) -> dict | list | None:
+    """
+    Return a YAML or JSON formatted string as a dict
+    """
+    if not contents.strip():
+        raise HopprLoadDataError("Empty string cannot be parsed.")
+
+    # Replace tab characters with spaces to prevent parsing errors
+    contents = contents.replace("\t", "  ")
+    loaded_contents: dict | list | None = None
 
     try:
-        plugin = importlib.import_module(plugin_name)
-    except ModuleNotFoundError as mnfe:
-        raise ModuleNotFoundError(
-            f"Unable to locate plug-in {plugin_name}: {mnfe}"
-        ) from mnfe
+        # Applicable to both YAML and JSON formats since valid JSON data is also valid YAML
+        loaded_contents = yaml.safe_load(contents)
 
-    plugin_obj = None
+        # yaml.safe_load will sometimes return a single string rather than the required structure
+        if isinstance(loaded_contents, str):
+            raise HopprLoadDataError("Expected dictionary or list, but contents were loaded and returned as string")
+    except (YAMLParserError, YAMLScannerError) as ex:
+        raise HopprLoadDataError("Unable to recognize data as either json or yaml") from ex
+    except HopprLoadDataError as ex:
+        raise HopprLoadDataError from ex
 
-    for name, obj in inspect.getmembers(plugin):
-        if _class_in_module(obj, plugin):
-
-            if plugin_obj is not None:
-                raise HopprPluginError(
-                    f"Multiple candidate classes defined in {plugin_name}: "
-                    + f"{plugin_obj.__name__}, {name}"
-                )
-
-            plugin_obj = obj
-
-    if plugin_obj is None:
-        raise HopprPluginError(f"No class definition found in in {plugin_name}.")
-
-    return plugin_obj(context=context, config=config)
+    return loaded_contents
 
 
-def load_string(contents: str) -> Dict:
+def load_file(input_file_path: Path) -> dict | list | None:
     """
-    Try loading yaml, json, and xml files into a dict.
-    """
-    try:
-        return_value = yaml.safe_load(contents)
-
-        ### yaml.safe_load will sometimes return a single string rather than
-        ### the required structure.  Treating that as a failure
-
-        if not isinstance(return_value, str):
-            return return_value
-    except (YamlParserError, YAMLScannerError):
-        pass
-
-    try:
-        return json.loads(contents)
-    except JSONDecodeError:
-        pass
-
-    raise HopprLoadDataError("Unable to recognize data as either json or yaml")
-
-
-def load_file(input_file_path: Path) -> Dict:
-    """
-    Load file content (either json or yml) into a dict
+    Load file content (either JSON or YAML) into a dict
     """
 
     if not input_file_path.is_file():
         raise HopprLoadDataError(f"{input_file_path} is not a file, cannot be opened.")
 
     with input_file_path.open(mode="r", encoding="utf-8") as input_file:
-        content = input_file.read()
-        return load_string(content)
+        content: str = input_file.read()
+        if not content.strip():
+            raise HopprLoadDataError(f"File {input_file_path} is empty.")
+
+    return load_string(content)
 
 
-def dedup_list(list_in: List[Any]) -> List[Any]:
+def dedup_list(list_in: list[Any]) -> list[Any]:
     """
     De-duplicate a list
     """
@@ -133,7 +148,7 @@ def obscure_passwords(command_list, lst):
     return command
 
 
-def remove_empty(directory: Path) -> Set[Path]:
+def remove_empty(directory: Path) -> set[Path]:
     """
     Removes empty folders given the directory including parent folders
     """
